# -*- coding: utf-8 -*-

mapping = (
    "abgdezhiklmnxoprstyfwuABGDEZHIKLMNXOPRSTYFWU",
    "αβγδεζηικλμνξοπρστυφωθΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΤΥΦΩΘ",
)
reversed_specific_mapping = (
    "θΘ",
    "uU"
)
pre_processor_mapping = {
    "th": "θ",
    "ch": "χ",
    "ps": "ψ",
    "TH": "Θ",
    "CH": "Χ",
    "PS": "Ψ",
}
