# -*- coding: utf-8 -*-

mapping = (
    u"abgdezhiklmnxoprstyfwuABGDEZHIKLMNXOPRSTYFWU",
    u"αβγδεζηικλμνξοπρστυφωθΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΤΥΦΩΘ",
)
reversed_specific_mapping = (
    u"θΘ",
    u"uU"
)
pre_processor_mapping = {
    u"th": u"θ",
    u"ch": u"χ",
    u"ps": u"ψ",
    u"TH": u"Θ",
    u"CH": u"Χ",
    u"PS": u"Ψ",
}
